diff --git a/web/pgadmin/static/js/backgrid.pgadmin.js b/web/pgadmin/static/js/backgrid.pgadmin.js
index 0d968aa..8275138 100644
--- a/web/pgadmin/static/js/backgrid.pgadmin.js
+++ b/web/pgadmin/static/js/backgrid.pgadmin.js
@@ -206,6 +206,11 @@ define([
             if(cell && cell.$el.hasClass('edit-cell') &&
               !cell.$el.hasClass('privileges') || cell.$el.hasClass('delete-cell')) {
               model.trigger('backgrid:next', m, n, false);
+              if(cell.$el.hasClass('delete-cell')) {
+                setTimeout(function(){
+                  $(cell.$el).trigger('focus');
+                }, 50);
+              }
               break;
             } else if (renderable && editable) {
               cell.enterEditMode();
diff --git a/web/pgadmin/static/scss/_pgadmin.style.scss b/web/pgadmin/static/scss/_pgadmin.style.scss
index 8f1e248..082e82c 100644
--- a/web/pgadmin/static/scss/_pgadmin.style.scss
+++ b/web/pgadmin/static/scss/_pgadmin.style.scss
@@ -741,6 +741,17 @@ table tr td {
   }
 }
 
+/* Specific to IE11 where we want to highlight the focus on grid buttons */
+@media all and (-ms-high-contrast: none), (-ms-high-contrast: active) {
+  table tr td {
+    td.edit-cell:focus,
+    td.delete-cell:focus,
+    td.string-cell:focus {
+      border: 2px solid $input-focus-border-color !important;;
+    }
+  }
+}
+
 .privilege_label{
   font-size: 10px!important;
 }
diff --git a/web/regression/javascript/dialog_tab_navigator_spec.js b/web/regression/javascript/dialog_tab_navigator_spec.js
index 8e86fc8..60e4bdd 100644
--- a/web/regression/javascript/dialog_tab_navigator_spec.js
+++ b/web/regression/javascript/dialog_tab_navigator_spec.js
@@ -11,7 +11,7 @@ import $ from 'jquery';
 import 'bootstrap';
 
 describe('dialogTabNavigator', function () {
-  let dialog, tabNavigator, backward_shortcut, forward_shortcut;
+  let dialog, tabNavigator, backward_shortcut, forward_shortcut, fakeEvent;
 
   beforeEach(() => {
     dialog = $('<div tabindex="1" class="backform-tab" role="tabpanel">'+
@@ -68,6 +68,9 @@ describe('dialogTabNavigator', function () {
 
     tabNavigator = new dialogTabNavigator.dialogTabNavigator(
       dialog, backward_shortcut, forward_shortcut);
+
+    fakeEvent = { stopPropagation: () => true };
+
   });
 
   describe('navigate', function () {
@@ -79,7 +82,7 @@ describe('dialogTabNavigator', function () {
     });
 
     it('navigate backward', function () {
-      tabNavigator.onKeyboardEvent({}, 'shift+ctrl+[');
+      tabNavigator.onKeyboardEvent(fakeEvent, 'shift+ctrl+[');
 
       expect(tabNavigator.navigateBackward).toHaveBeenCalled();
 
@@ -88,7 +91,7 @@ describe('dialogTabNavigator', function () {
     });
 
     it('navigate forward', function () {
-      tabNavigator.onKeyboardEvent({}, 'shift+ctrl+]');
+      tabNavigator.onKeyboardEvent(fakeEvent, 'shift+ctrl+]');
 
       expect(tabNavigator.navigateForward).toHaveBeenCalled();
 
@@ -97,7 +100,7 @@ describe('dialogTabNavigator', function () {
     });
 
     it('should not navigate', function () {
-      tabNavigator.onKeyboardEvent({}, 'shift+ctrl+a');
+      tabNavigator.onKeyboardEvent(fakeEvent, 'shift+ctrl+a');
 
       expect(tabNavigator.navigateForward).not.toHaveBeenCalled();
 
@@ -115,7 +118,8 @@ describe('dialogTabNavigator', function () {
 
       navigateForwardResult = tabNavigator.navigateForward(
         dialog.find('ul.nav-tabs:first'),
-        dialog.find('div#1')
+        dialog.find('div#1'),
+        fakeEvent
       );
     });
 
@@ -141,7 +145,8 @@ describe('dialogTabNavigator', function () {
 
       navigateForwardResult = tabNavigator.navigateForward(
         dialog.find('ul.nav-tabs:first'),
-        dialog.find('div#1')
+        dialog.find('div#1'),
+        fakeEvent
       );
     });
 
@@ -165,7 +170,8 @@ describe('dialogTabNavigator', function () {
 
       navigateBackwardResult = tabNavigator.navigateBackward(
         dialog.find('ul.nav-tabs:first'),
-        dialog.find('div#1')
+        dialog.find('div#1'),
+        fakeEvent
       );
     });
 
@@ -184,7 +190,8 @@ describe('dialogTabNavigator', function () {
 
       navigateBackwardResult = tabNavigator.navigateBackward(
         dialog.find('ul.nav-tabs:first'),
-        dialog.find('div#1')
+        dialog.find('div#1'),
+        fakeEvent
       );
     });
 
